@@ -1,8 +1,6 @@
 /*
  * Copyright (C) Internet Systems Consortium, Inc. ("ISC")
  *
- * SPDX-License-Identifier: MPL-2.0
- *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, you can obtain one at https://mozilla.org/MPL/2.0/.
@@ -11,12 +9,12 @@
  * information regarding copyright ownership.
  */
 
-#pragma once
+#ifndef NS_ZONECONF_H
+#define NS_ZONECONF_H 1
 
 /*! \file */
 
 #include <stdbool.h>
-
 #include <isc/lang.h>
 #include <isc/types.h>
 
@@ -26,27 +24,26 @@
 ISC_LANG_BEGINDECLS
 
 isc_result_t
-named_zone_configure(const cfg_obj_t *config, const cfg_obj_t *vconfig,
-		     const cfg_obj_t *zconfig, cfg_aclconfctx_t *ac,
-		     dns_kasplist_t *kasplist, dns_zone_t *zone,
-		     dns_zone_t *raw);
+ns_zone_configure(const cfg_obj_t *config, const cfg_obj_t *vconfig,
+		  const cfg_obj_t *zconfig, cfg_aclconfctx_t *ac,
+		  dns_zone_t *zone, dns_zone_t *raw);
 /*%<
  * Configure or reconfigure a zone according to the named.conf
- * data.
+ * data in 'cctx' and 'czone'.
  *
  * The zone origin is not configured, it is assumed to have been set
  * at zone creation time.
  *
  * Require:
- * \li	'ac' to point to an initialized cfg_aclconfctx_t.
- * \li	'kasplist' to be initialized.
+ * \li	'lctx' to be initialized or NULL.
+ * \li	'cctx' to be initialized or NULL.
+ * \li	'ac' to point to an initialized ns_aclconfctx_t.
+ * \li	'czone' to be initialized.
  * \li	'zone' to be initialized.
  */
 
 bool
-named_zone_reusable(dns_zone_t *zone, const cfg_obj_t *zconfig,
-		    const cfg_obj_t *vconfig, const cfg_obj_t *config,
-		    dns_kasplist_t *kasplist);
+ns_zone_reusable(dns_zone_t *zone, const cfg_obj_t *zconfig);
 /*%<
  * If 'zone' can be safely reconfigured according to the configuration
  * data in 'zconfig', return true.  If the configuration data is so
@@ -54,18 +51,9 @@ named_zone_reusable(dns_zone_t *zone, const cfg_obj_t *zconfig,
  * and recreated, return false.
  */
 
-bool
-named_zone_inlinesigning(const cfg_obj_t *zconfig, const cfg_obj_t *vconfig,
-			 const cfg_obj_t *config, dns_kasplist_t *kasplist);
-/*%<
- * Determine if zone uses inline-signing. This is true if inline-signing
- * is set to yes, in the zone clause or in the zone's dnssec-policy clause.
- * By default, dnssec-policy uses inline-signing.
- */
-
 isc_result_t
-named_zone_configure_writeable_dlz(dns_dlzdb_t *dlzdatabase, dns_zone_t *zone,
-				   dns_rdataclass_t rdclass, dns_name_t *name);
+ns_zone_configure_writeable_dlz(dns_dlzdb_t *dlzdatabase, dns_zone_t *zone,
+				dns_rdataclass_t rdclass, dns_name_t *name);
 /*%>
  * configure a DLZ zone, setting up the database methods and calling
  * postload to load the origin values
@@ -78,3 +66,5 @@ named_zone_configure_writeable_dlz(dns_dlzdb_t *dlzdatabase, dns_zone_t *zone,
  */
 
 ISC_LANG_ENDDECLS
+
+#endif /* NS_ZONECONF_H */
