@@ -3,7 +3,7 @@
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
+ * file, you can obtain one at https://mozilla.org/MPL/2.0/.
  *
  * See the COPYRIGHT file distributed with this work for additional
  * information regarding copyright ownership.
@@ -131,14 +131,17 @@ compare_nsec(ARGS_COMPARE) {
 
 static inline isc_result_t
 fromstruct_nsec(ARGS_FROMSTRUCT) {
-	dns_rdata_nsec_t *nsec = source;
+	dns_rdata_nsec_t *nsec;
 	isc_region_t region;
 
 	REQUIRE(type == dns_rdatatype_nsec);
-	REQUIRE(nsec != NULL);
-	REQUIRE(nsec->common.rdtype == type);
-	REQUIRE(nsec->common.rdclass == rdclass);
-	REQUIRE(nsec->typebits != NULL || nsec->len == 0);
+	REQUIRE(((dns_rdata_nsec_t *)source) != NULL);
+	REQUIRE(((dns_rdata_nsec_t *)source)->common.rdtype == type);
+	REQUIRE(((dns_rdata_nsec_t *)source)->common.rdclass == rdclass);
+	REQUIRE(((dns_rdata_nsec_t *)source)->typebits != NULL ||
+		((dns_rdata_nsec_t *)source)->len == 0);
+
+	nsec = source;
 
 	UNUSED(type);
 	UNUSED(rdclass);
@@ -155,13 +158,15 @@ fromstruct_nsec(ARGS_FROMSTRUCT) {
 static inline isc_result_t
 tostruct_nsec(ARGS_TOSTRUCT) {
 	isc_region_t region;
-	dns_rdata_nsec_t *nsec = target;
+	dns_rdata_nsec_t *nsec;
 	dns_name_t name;
 
+	REQUIRE(((dns_rdata_nsec_t *)target) != NULL);
 	REQUIRE(rdata->type == dns_rdatatype_nsec);
-	REQUIRE(nsec != NULL);
 	REQUIRE(rdata->length != 0);
 
+	nsec = target;
+
 	nsec->common.rdclass = rdata->rdclass;
 	nsec->common.rdtype = rdata->type;
 	ISC_LINK_INIT(&nsec->common, link);
@@ -189,10 +194,13 @@ tostruct_nsec(ARGS_TOSTRUCT) {
 
 static inline void
 freestruct_nsec(ARGS_FREESTRUCT) {
-	dns_rdata_nsec_t *nsec = source;
+	dns_rdata_nsec_t *nsec;
 
-	REQUIRE(nsec != NULL);
-	REQUIRE(nsec->common.rdtype == dns_rdatatype_nsec);
+	REQUIRE(((dns_rdata_nsec_t *)source) != NULL);
+	REQUIRE(((dns_rdata_nsec_t *)source)->common.rdtype ==
+		dns_rdatatype_nsec);
+
+	nsec = source;
 
 	if (nsec->mctx == NULL)
 		return;
